@@ -10,13 +10,15 @@
 
 
 __title__   = 'qwak'
-__version__ = '0.1'
+__version__ = '0.2'
 __author__  = '@c0ding'
 __repo__    = 'https://github.com/c0ding/qwak'
 __license__ = 'Apache v2.0 License'
 
 import qwak_utils
 from qwak_api import (
-	public, user_status, user_balance, user_sharerate, user_transactions, 
-	user_workers, user_dashboard, user_navbar
-)
\ No newline at end of file
+	public, pool_info, pool_status, pool_hashrate, hourly_hashrates, pool_sharerate,
+	block_last, block_count, blocks_found, blocks_stats, difficulty, current_workers,
+	top_contributors, estimated_time, user_status, user_balance, user_hashrate,
+	user_sharerate, user_transactions, user_workers, dashboard, navbar,
+)
